@@ -18,7 +18,13 @@
  *
  */
 
-var ContactFinder = function() {
+var ContactFinder = function(options) {
+    if (typeof options === 'undefined') {
+        options = {};
+    }
+    this.complaintEmailSubject = options.complaintEmailSubject;
+    this.complaintEmailBody = options.complaintEmailBody;
+
     // initial full list of links
     // on a page.
     this.pageLinks = null;
@@ -177,13 +183,13 @@ ContactFinder.prototype.searchForSocialMedia = function (link) {
     }
 
     if (eventType) {
-        self.postMessage(
-            { event: eventType,
-              contact: {
-                  'label': text,
-                  'link': elem.attr('href')}
+        self.postMessage({
+            event: eventType,
+            contact: {
+                'label': text,
+                'link': elem.attr('href')
             }
-        );
+        });
         return true;
     }
 
@@ -230,22 +236,31 @@ ContactFinder.prototype.searchForContactEmail = function (link) {
             // not the same hostname... we'll keep it just in case.
             eventType = linkTypes.UNCERTAIN_EMAIL_ADDRESS_FOUND;
         }
-
     } else if (reAnyEmail.test(elem.attr('href'))) {
-
         if (this.isSameHostname(elem.attr('href'))) {
             eventType = linkTypes.UNCERTAIN_EMAIL_ADDRESS_FOUND;
         }
-
     }
+
     if (eventType) {
+        var label = elem.attr('href').replace('mailto:', '');
+        var myLink = elem.attr('href');
+
+        // Add customizable complaintEmailSubject and complaintEmailBody to
+        // mailto link
+        if (this.complaintEmailSubject && this.complaintEmailBody) {
+            myLink = myLink + '?subject=' + this.complaintEmailSubject +
+                '&body=' + this.complaintEmailBody;
+        }
+
         // we found an email address.
         // send message with whatever event type was found.
         self.postMessage({
             event: eventType,
             contact: {
-                'label': elem.attr('href').replace('mailto:', ''),
-                'link': elem.attr('href')}
+                'label': label,
+                'link': myLink
+            }
         });
         return true;
     } else {
@@ -301,13 +316,13 @@ ContactFinder.prototype.matchContactLink = function (currentLink) {
 
                     if (degreeName === 'certain') {
 
-                        self.postMessage(
-                            { event: linkTypes.CERTAIN_LINK_FOUND,
-                              contact: {
-                                  'label': text,
-                                  'link': href}
+                        self.postMessage({
+                            event: linkTypes.CERTAIN_LINK_FOUND,
+                            contact: {
+                                'label': text,
+                                'link': href
                             }
-                        );
+                        });
 
                         if (!that.isPageWorker) {
                             that.complaintSearch(linkTypes.CERTAIN_LINK_FOUND, href);
@@ -315,25 +330,25 @@ ContactFinder.prototype.matchContactLink = function (currentLink) {
 
                     } else if (degreeName === 'probable'){
 
-                        self.postMessage(
-                            { event: linkTypes.PROBABLE_LINK_FOUND,
-                              contact: {
-                                  'label': text,
-                                  'link': href}
+                        self.postMessage({
+                            event: linkTypes.PROBABLE_LINK_FOUND,
+                            contact: {
+                                'label': text,
+                                'link': href
                             }
-                        );
+                        });
 
                         if (!that.isPageWorker) {
                             that.complaintSearch(linkTypes.PROBABLE_LINK_FOUND, href);
                         }
                     } else if (degreeName === 'uncertain') {
-                        self.postMessage(
-                            { event: linkTypes.UNCERTAIN_LINK_FOUND,
-                              contact: {
-                                  'label': text,
-                                  'link': href}
+                        self.postMessage({
+                            event: linkTypes.UNCERTAIN_LINK_FOUND,
+                            contact: {
+                                'label': text,
+                                'link': href
                             }
-                        );
+                        });
 
                         if (!that.isPageWorker) {
                             that.complaintSearch(
@@ -381,8 +396,7 @@ ContactFinder.prototype.getHostname = function (str) {
 
     if (match1) {
         return match1[1];
-    }
-    else if (match2) {
+    } else if (match2) {
         return match2[1];
     }
 
