@@ -54,13 +54,16 @@ var displayPanel = {
         // start listening for messages sent from modules.
         this.messageListen();
         this.openInNewTab();
-        this.logoClick();
+        this.startEventHandlers();
     },
-    logoClick: function () {
+    startEventHandlers: function () {
         $("#ljs-settings").click(function (e) {
             e.preventDefault();
             self.port.emit('openSesame');
         });
+        $('#librejs-web-link').click(function() {
+            self.port.emit('hideMainPanel');
+        });
     },
     openInNewTab: function () {
         $('#open-in-tab').click(function (e) {
@@ -157,7 +160,7 @@ var displayPanel = {
         this.complainButton.off('click');
         this.complainButton.click(function(e) {
             e.preventDefault();
-            self.port.emit('complainButtonClicked');
+            self.port.emit('hideMainPanel');
             window.open(url, '_blank');
         });
     },
@@ -256,7 +259,7 @@ var displayPanel = {
                 $('#report').attr(
                     'href',
                     'mailto:bug-librejs@gnu.org' +
-                        '?subject=LibreJS bug Report' +
+                        '?subject=LibreJS bug report' +
                         '&body=LibreJS issue with page: ' +
                         message.pageURL);
             }
