@@ -55,7 +55,7 @@ WebLabelFinder.prototype.init = function(dom, pageURL, callback) {
     this.pageURL = pageURL;
     this.dom = dom;
     this.callback = function (a) { 
-        if (typeof a == 'undefined') {
+        if (typeof a === 'undefined') {
             a = null;
         }
 
@@ -95,26 +95,31 @@ WebLabelFinder.prototype.searchForJsLink = function() {
 
         // loop through all a tags.
         for (; i < len; i++) {
-            if (linkTags[i].hasAttribute('rel') &&
-                linkTags[i].getAttribute('rel') === 'jslicense') {
+            if (
+                (linkTags[i].hasAttribute('rel') &&
+                 linkTags[i].getAttribute('rel') === 'jslicense') ||
+                    (linkTags[i].hasAttribute('data-jslicense') &&
+                     linkTags[i].getAttribute('data-jslicense') === '1')
+            ) {
                 return this.formatURL(linkTags[i]);
             }
         }
     }
     // no js web labels were found. call back.
     this.callback();
+    return false;
 };
 
 WebLabelFinder.prototype.formatURL = function(link) {
     this.jslicenseURL = urlHandler.resolve(this.pageURL, link.href);
     this.jslicenseURL = urlHandler.addFragment(this.jslicenseURL, 'librejs=true');
     console.debug('license URL found', this.jslicenseURL);
+    return this.jslicenseURL;
 };
 
 WebLabelFinder.prototype.fetchLicensePage = function() {
     var that = this;
     try {
-
         var req =  Cc["@mozilla.org/xmlextras/xmlhttprequest;1"].createInstance();
 
         req.onload = function() {
@@ -129,14 +134,12 @@ WebLabelFinder.prototype.fetchLicensePage = function() {
             // object for dynamically embedded scripts.
             jsWebLabelEntries[that.pageURL] = that.licenseList;
             jsLabelsPageVisited[req._url] = 1;
-
         };
         console.debug(this.jslicenseURL);
         req.open('GET', this.jslicenseURL, true);
         req._url = this.jslicenseURL;
         req.responseType = "document";
         req.send();
-
     } catch (e) {
         console.debug(e, e.lineNumber, e.fileName, this.jslicenseURL);
         this.callback({});
@@ -160,7 +163,7 @@ WebLabelFinder.prototype.matchListWithDefs = function(jslicenseURL) {
     var callback = function (url) {
         cacheCalls++;
         list_check[url] = 1;
-        if (cacheCalls == Object.keys(list_check).length) {
+        if (cacheCalls === Object.keys(list_check).length) {
             console.debug("triggering callback duh");
             // return array to requester object
             callback = false;
@@ -183,7 +186,7 @@ WebLabelFinder.prototype.matchListWithDefs = function(jslicenseURL) {
         for (license in licenses) {
             licDef = licenses[license];
             if (licDef.canonicalUrl !== undefined) {
-                if (typeof licDef.canonicalUrl == 'string') {
+                if (typeof licDef.canonicalUrl === 'string') {
                     // this is a string. make it an array.
                     licArray = [licDef.canonicalUrl];
                 }  else {
@@ -193,13 +196,15 @@ WebLabelFinder.prototype.matchListWithDefs = function(jslicenseURL) {
                 urlLength = licArray.length;
 
                 for (iUrl = 0; iUrl < urlLength; iUrl++) {
-                    if (urlHandler.removeFragment(licArray[iUrl]) === urlHandler.removeFragment(lic.licenseUrl)) {
+                    if (urlHandler.removeFragment(licArray[iUrl]) ===
+                        urlHandler.removeFragment(lic.licenseUrl)) {
                         if (!require("sdk/url").isValidURI(lic.fileUrl)) {
                             console.debug(lic.fileUrl, " is not a valid URL");
                             callback();
                         }
                         lic.free = true;
-                        var notif = require("ui/notification").createNotification(lic.fileUrl).notification;
+                        var notif = require("ui/notification")
+                            .createNotification(lic.fileUrl).notification;
                         console.debug("about TO ADD TO XHR: ", lic.fileUrl);
                         list_check[lic.fileUrl] = 0;
                         addToCache(lic, 0, jslicenseURL, callback);
