@@ -28,7 +28,7 @@ var scriptsCached = require("./scripts_cache").scriptsCached;
 // find the json database path.
 var dbContents = require("sdk/self").data.load("script_libraries/script-libraries.json");
 
-const AUTHOR_REASON = "this script has been tagged as free software by LibreJS authors";
+const AUTHOR_REASON = "This script has been tagged as free software by LibreJS authors.";
 
 var freeLibraries = JSON.parse(dbContents); /* a database of the free libraries recognized by default */
 
