@@ -25,7 +25,7 @@ var pageMod = require("sdk/page-mod");
 var urlHandler = require("url_handler/url_handler");
 var pageWorker = require("sdk/page-worker");
 var tabs = require("sdk/tabs");
-var isComplaintTab = require("addon_management/prefchange").isComplaintTab;
+var prefs = require("addon_management/prefchange");
 
 // contain list of recently found contact links or email addresses.
 var contactList = {};
@@ -70,7 +70,7 @@ pageMod.PageMod({
     ],
 
     onAttach: function onAttach(worker) {
-        if (worker.tab !== undefined && isComplaintTab()) {
+        if (worker.tab !== undefined && prefs.isComplaintTab()) {
             // this is a tab.
             if (!foundInContactList(worker.url)) {
                 // the hostname doesn't appear in the object literal.
@@ -115,6 +115,11 @@ var tabProcess = function (worker) {
     modUrl = worker.url;
     console.debug('pagemod triggered');
 
+    worker.port.emit('prefs', {
+        complaintEmailSubject: prefs.complaintEmailSubject(),
+        complaintEmailBody: prefs.complaintEmailBody()
+    });
+
     // send local path to complain button graphic.
     worker.port.emit('assetsUri',
                      {'event': 'assets-uri',
