@@ -31,7 +31,7 @@ exports.testDetectEmailAddressFound = function (test) {
 
 	contentScriptFile: [data.url('complain/contact_regex.js'),
 			    data.url('complain/link_types.js'),
-			    data.url('third_party/jquery-src.js'), 
+			    data.url('settings/third-party/jquery/jquery.min.js'), 
 			    data.url('third_party/jquery.easing.1.3.js'),
 			    data.url('complain/contact_finder.js')],
 
@@ -64,7 +64,7 @@ exports.testDetectEmailAddressFoundTwoLinks = function (test) {
 
 	contentScriptFile: [data.url('complain/contact_regex.js'),
 			    data.url('complain/link_types.js'),
-			    data.url('third_party/jquery-src.js'), 
+			    data.url('settings/third-party/jquery/jquery.min.js'), 
 			    data.url('third_party/jquery.easing.1.3.js'),
 			    data.url('complain/contact_finder.js')],
 
@@ -98,7 +98,7 @@ exports.testDetectEmailAddressNotDomain = function (test) {
 
 	contentScriptFile: [data.url('complain/contact_regex.js'),
 			    data.url('complain/link_types.js'),
-			    data.url('third_party/jquery-src.js'), 
+			    data.url('settings/third-party/jquery/jquery.min.js'), 
 			    data.url('third_party/jquery.easing.1.3.js'),
 			    data.url('complain/contact_finder.js')],
 
@@ -128,7 +128,7 @@ exports.testCertainLink = function (test) {
 
 	contentScriptFile: [data.url('complain/contact_regex.js'),
 			    data.url('complain/link_types.js'),
-			    data.url('third_party/jquery-src.js'), 
+			    data.url('settings/third-party/jquery/jquery.min.js'), 
 			    data.url('third_party/jquery.easing.1.3.js'),
 			    data.url('complain/contact_finder.js')],
 
@@ -158,7 +158,7 @@ exports.testCertainReal = function (test) {
 
 	contentScriptFile: [data.url('complain/contact_regex.js'),
 			    data.url('complain/link_types.js'),
-			    data.url('third_party/jquery-src.js'), 
+			    data.url('settings/third-party/jquery/jquery.min.js'), 
 			    data.url('third_party/jquery.easing.1.3.js'),
 			    data.url('complain/contact_finder.js')],
 
@@ -189,7 +189,7 @@ exports.testCertainFeedbackAsPageWorker = function (test) {
 
 	contentScriptFile: [data.url('complain/contact_regex.js'),
 			    data.url('complain/link_types.js'),
-			    data.url('third_party/jquery-src.js'), 
+			    data.url('settings/third-party/jquery/jquery.min.js'), 
 			    data.url('third_party/jquery.easing.1.3.js'),
 			    data.url('complain/contact_finder.js')],
 
